@@ -24,9 +24,16 @@ func Test_runAndReplace(t *testing.T) {
 		{"", "${{123}}", echo, "123", false},
 		{"", "${{      123  }}", echo, "123", false},
 		{"", "${{ 123 }}", echo, "123", false},
-		{"", "123${{ 456\n }}789", echo, "123456\n789", false},
+		{"", "123${{ 456 }}789", echo, "123456789", false},
 		{"", "${{ 123 }} ${{ 456 }}", echo, "123 456", false},
 		{"", "${{ 123 ${{ 456 }} }}", echo, "123 456", false},
+		{"", "${{123}}\n456", echo, "123\n456", false},
+		{"comment", "123#456", echo, "123#456", false},
+		{"comment", "123 #456", echo, "123 #456", false},
+		{"comment", "#456}}${{ 123 }}", echo, "#456}}${{ 123 }}", false},
+		{"comment", "${{ 123 }} #456}}", echo, "123 #456}}", false},
+		{"nest", "${{ 123 ${{ 456 }} }}", echo, "123 456", false},
+		{"nest", "${{ 123${{456${{789}}}}}}", echo, "123456789", false},
 		{"dead loop", "${{ 123 }}", deadLoopEcho, "", true},
 		{"invalid syntax", "${{ 123 }}}}", echo, "", true},
 		{"invalid syntax", "${{ 123 }", echo, "", true},
